summaryrefslogtreecommitdiff
path: root/src/components/connection_handler/include/connection_handler/connection_handler_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/components/connection_handler/include/connection_handler/connection_handler_impl.h')
-rw-r--r--src/components/connection_handler/include/connection_handler/connection_handler_impl.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/components/connection_handler/include/connection_handler/connection_handler_impl.h b/src/components/connection_handler/include/connection_handler/connection_handler_impl.h
index d073d06aa1..4c0c7b2985 100644
--- a/src/components/connection_handler/include/connection_handler/connection_handler_impl.h
+++ b/src/components/connection_handler/include/connection_handler/connection_handler_impl.h
@@ -145,11 +145,11 @@ class ConnectionHandlerImpl
void OnDeviceSwitchingStart(const std::string& device_uid) FINAL;
/**
* @brief OnDeviceSwitchFinish notifies listeners on device transport
* switching completion
* @param device_uid the id for the device which is fails to reconnect.
*/
- void OnDeviceSwitchFinish(
+ void OnDeviceSwitchingFinish(
const transport_manager::DeviceUID& device_uid) FINAL;
void OnScanDevicesFinished() OVERRIDE;
@@ -145,11 +145,11 @@ class ConnectionHandlerImpl
void OnDeviceSwitchingStart(const std::string& device_uid) FINAL;
/**
- * @brief OnDeviceSwitchFinish notifies listeners on device transport
+ * @brief OnDeviceSwitchingFinish notifies listeners on device transport
* switching completion
* @param device_uid the id for the device which is fails to reconnect.